@@ -13,6 +13,7 @@ use super::{
     layer::{SecureLayer, SecureLayerError},
 };
 
+#[derive(Debug)]
 pub struct SecureStream<S> {
     layer: SecureLayer<S>,
     read_buf: VecBuf,
@@ -42,9 +43,11 @@ impl<S> SecureStream<S> {
 
 impl<S: Read> Read for SecureStream<S> {
     fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
-        let chunk = self.layer.read().map_err(io_error_map)?;
+        if self.read_buf.is_empty() {
+            let chunk = self.layer.read().map_err(io_error_map)?;
 
-        self.read_buf.push(chunk);
+            self.read_buf.push(chunk);
+        }
 
         self.read_buf.read(buf)
     }
