@@ -7,6 +7,7 @@
 use std::{collections::VecDeque, io::{Cursor, Read, Write}};
 
 /// Store buffers read
+#[derive(Debug)]
 pub struct VecBuf {
     
     deque: VecDeque<Vec<u8>>
@@ -26,6 +27,10 @@ impl VecBuf {
         self.deque.push_back(chunk)
     }
 
+    pub fn is_empty(&self) -> bool {
+        self.deque.len() <= 0
+    }
+
 }
 
 impl Read for VecBuf {
